@@ -2,7 +2,7 @@ from doc_datatypes.datatypes import DocumentedIndex, DocumentedValue
 
 
 def test_documented_value():
-    name_value = DocumentedValue(value="Alex", doc="Name field")
+    name_value: DocumentedValue[str] = DocumentedValue(value="Alex", doc="Name field")
 
     assert isinstance(name_value, DocumentedValue)
     assert name_value() == "Alex"
@@ -13,7 +13,7 @@ def test_documented_value():
 
 
 def test_documented_index():
-    name_index = DocumentedIndex(value="Alex", doc="Name field")
+    name_index: DocumentedIndex[str] = DocumentedIndex(value="Alex", doc="Name field")
 
     assert isinstance(name_index, DocumentedIndex)
     assert name_index() == "Alex"
